==> huaweicloudsdkddm-3.0.52-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/update_user_request.py <==
# coding: utf-8

import re
import six





class UpdateUserRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'username': 'str',
        'body': 'UpdateUserReq'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'username': 'username',
        'body': 'body'
    }

    def __init__(self, instance_id=None, username=None, body=None):
        """UpdateUserRequest - a model defined in huaweicloud sdk"""
        
        

        self._instance_id = None
        self._username = None
        self._body = None
        self.discriminator = None

        self.instance_id = instance_id
        self.username = username
        if body is not None:
            self.body = body

    @property
    def instance_id(self):
        """Gets the instance_id of this UpdateUserRequest.

        DDM实例ID。

        :return: The instance_id of this UpdateUserRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this UpdateUserRequest.

        DDM实例ID。

        :param instance_id: The instance_id of this UpdateUserRequest.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def username(self):
        """Gets the username of this UpdateUserRequest.

        需要修改的DDM帐号名称。

        :return: The username of this UpdateUserRequest.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UpdateUserRequest.

        需要修改的DDM帐号名称。

        :param username: The username of this UpdateUserRequest.
        :type: str
        """
        self._username = username

    @property
    def body(self):
        """Gets the body of this UpdateUserRequest.


        :return: The body of this UpdateUserRequest.
        :rtype: UpdateUserReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateUserRequest.


        :param body: The body of this UpdateUserRequest.
        :type: UpdateUserReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUserRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/update_user_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateUserRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'username': 'str',
        'body': 'UpdateUserReq'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'username': 'username',
        'body': 'body'
    }

    def __init__(self, instance_id=None, username=None, body=None):
        """UpdateUserRequest - a model defined in huaweicloud sdk"""
        
        

        self._instance_id = None
        self._username = None
        self._body = None
        self.discriminator = None

        self.instance_id = instance_id
        self.username = username
        if body is not None:
            self.body = body

    @property
    def instance_id(self):
        """Gets the instance_id of this UpdateUserRequest.

        DDM实例ID。

        :return: The instance_id of this UpdateUserRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this UpdateUserRequest.

        DDM实例ID。

        :param instance_id: The instance_id of this UpdateUserRequest.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def username(self):
        """Gets the username of this UpdateUserRequest.

        需要修改的DDM帐号名称。

        :return: The username of this UpdateUserRequest.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UpdateUserRequest.

        需要修改的DDM帐号名称。

        :param username: The username of this UpdateUserRequest.
        :type: str
        """
        self._username = username

    @property
    def body(self):
        """Gets the body of this UpdateUserRequest.


        :return: The body of this UpdateUserRequest.
        :rtype: UpdateUserReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateUserRequest.


        :param body: The body of this UpdateUserRequest.
        :type: UpdateUserReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUserRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
